OC.L10N.register(
    "settings",
    {
    "Private" : "Прыватна",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Бачна толькі людзям, якія супалі праз інтэграцыю нумара тэлефона з дапамогай Talk на мабільным тэлефоне",
    "Local" : "Лакальна",
    "Only visible to people on this instance and guests" : "Бачна толькі карыстальнікам гэтага сервера і гасцям",
    "Federated" : "Федэратыўны",
    "Only synchronize to trusted servers" : "Сінхранізацыя толькі з даверанымі серверамі",
    "Published" : "Апублікавана",
    "Synchronize to trusted servers and the global and public address book" : "Сінхранізацыя з даверанымі серверамі і глабальнай і публічнай адраснай кнігай",
    "Verify" : "Спраўдзіць",
    "Verifying …" : "Спраўджанне …",
    "Unable to change password" : "Немагчыма змяніць пароль",
    "Very weak password" : "Вельмі слабы пароль",
    "Weak password" : "Слабы пароль",
    "So-so password" : "Абы-які пароль",
    "Good password" : "Файны пароль",
    "Strong password" : "Моцны пароль",
    "Groups" : "Групы",
    "Group list is empty" : "Спіс груп пусты",
    "{actor} added you to group {group}" : "{actor} дадаў(-ла) вас у групу {group}",
    "You added {user} to group {group}" : "Вы дадалі {user} у групу {group}",
    "{actor} added {user} to group {group}" : "{actor} дадаў(-ла) {user} у групу {group}",
    "An administrator added you to group {group}" : "Адміністратар дадаў вас у групу {group}",
    "An administrator added {user} to group {group}" : "Адміністратар дадаў {user} у групу {group}",
    "You changed your password" : "Вы змянілі свой пароль.",
    "Your password was reset by an administrator" : "Ваш пароль быў скінуты адміністратарам",
    "Your password was reset" : "Ваш пароль быў скінуты",
    "You created an app password for a session named \"{token}\"" : "Вы стварылі пароль праграмы для сеанса пад назвай \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Адміністратар стварыў пароль праграмы для сеанса пад назвай \"{token}\"",
    "You deleted app password \"{token}\"" : "Вы выдалілі пароль праграмы \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Вы перайменавалі пароль праграмы \"{token}\" на \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Вы далі доступ да файлавай сістэмы для пароля праграмы \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Вы адклікалі доступ да файлавай сістэмы для пароля праграмы \"{token}\"",
    "Security" : "Бяспека",
    "Settings" : "Налады",
    "Could not remove app." : "Не ўдалося выдаліць праграму.",
    "Could not update app." : "Не ўдалося абнавіць праграму.",
    "Wrong password" : "Няправільны пароль",
    "Saved" : "Захавана",
    "Authentication error" : "Памылка аўтэнтыфікацыі",
    "Recently active" : "Нядаўна актыўныя",
    "Disabled accounts" : "Адключаныя ўліковыя запісы",
    "Settings saved" : "Налады захаваны",
    "Unable to change full name" : "Немагчыма змяніць поўнае імя",
    "Your %s account was created" : "Ваш уліковы запіс %s створаны.",
    "Your Login is: %s" : "Ваш лагін: %s",
    "Go to %s" : "Перайсці да %s",
    "Install Client" : "Усталяваць кліент",
    "Apps" : "Праграмы",
    "Personal" : "Асабістыя",
    "Administration" : "Адміністратар",
    "Users" : "Карыстальнікі",
    "Additional settings" : "Дадатковыя налады",
    "Assistant" : "Памочнік",
    "Administration privileges" : "Прывілеі адміністратара",
    "Overview" : "Агляд",
    "Basic settings" : "Асноўныя налады",
    "Sharing" : "Абагульванне",
    "Availability" : "Даступнасць",
    "Calendar" : "Каляндар",
    "Personal info" : "Асабістыя звесткі",
    "Artificial Intelligence" : "Штучны інтэлект",
    "Email server" : "Сервер электроннай пошты",
    "User's email account" : "Уліковы запіс электроннай пошты карыстальніка",
    "System email account" : "Сістэмны ўліковы запіс электроннай пошты",
    "Verifying" : "Спраўджанне",
    "Your remote address could not be determined." : "Не ўдалося вызначыць ваш аддалены адрас.",
    "Cron errors" : "Памылкі cron",
    "Cron last run" : "Апошні запуск cron",
    "Database missing indices" : "Адсутнічаюць індэксы ў базе даных",
    "Missing indices:" : "Адсутнічаюць індэксы:",
    "\"%s\" in table \"%s\"" : "\"%s\" у табліцы \"%s\"",
    "Database pending bigint migrations" : "База даных чакае міграцыі bigint",
    "Debug mode" : "Рэжым адладкі",
    "Debug mode is disabled." : "Рэжым адладкі адключаны.",
    "Disabled" : "Адключана",
    "MySQL row format" : "Фармат радкоў MySQL",
    "You are not using MySQL" : "Вы не выкарыстоўваеце MySQL",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "Функцыя даступна.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Функцыя PHP \"set_time_limit\" недаступна. Гэта можа прывесці да спынення выканання скрыптоў, што парушыць усталяванне. Настойліва рэкамендуем уключыць гэту функцыю.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Ваш PHP не падтрымлівае FreeType, што прыводзіць да пашкоджання аватараў профілю і інтэрфейсе налад.",
    "PHP getenv" : "PHP getenv",
    "PHP opcache" : "PHP opcache",
    "PHP version" : "Версія PHP",
    "You are currently running PHP %s." : "Вы зараз выкарыстоўваеце PHP %s.",
    "PHP \"output_buffering\" option" : "Параметр PHP \"output_buffering\"",
    "PHP configuration option \"output_buffering\" must be disabled" : "Параметр канфігурацыі PHP \"output_buffering\" павінен быць адключаны",
    "HTTP headers" : "Загалоўкі HTTP",
    "Database version" : "Версія базы даных",
    "Unknown database platform" : "Невядомая платформа базы даных",
    "Architecture" : "Архітэктура",
    "64-bit" : "64-бітная",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Ваша база даных не працуе з узроўнем ізаляцыі транзакцый \"READ COMMITTED\". Гэта можа выклікаць праблемы пры паралельным выкананні некалькіх дзеянняў.",
    "Font file loading" : "Загрузка файла шрыфту",
    "Profile information" : "Звесткі профілю",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Аватар профілю, поўнае імя, адрас электроннай пошты, нумар тэлефона, адрас, вэб-сайт, Twitter, арганізацыя, роля, загаловак, біяграфія і ці ўключаны ваш профіль",
    "Nextcloud settings" : "Налады Nextcloud",
    "Enable" : "Уключыць",
    "Machine translation" : "Машынны пераклад",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Машынны пераклад можа быць рэалізаваны рознымі праграмамі. Тут вы можаце вызначыць прыярытэт праграм машыннага перакладу, якія ў вас усталяваны ў дадзены момант.",
    "Image generation" : "Генерацыя відарысаў",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Генерацыя відарысаў можа быць рэалізавана рознымі праграмамі. Тут вы можаце задаць, якую праграму трэба выкарыстоўваць.",
    "None of your currently installed apps provide image generation functionality" : "Ніводная з усталяваных праграм не прадугледжвае функцыі генерацыі відарысаў",
    "Text processing" : "Апрацоўка тэксту",
    "Here you can decide which group can access certain sections of the administration settings." : "Тут вы можаце вызначыць, якая група мае доступ да пэўных раздзелаў налад адміністравання.",
    "Unable to modify setting" : "Немагчыма змяніць наладу",
    "None" : "Няма",
    "Changed disclaimer text" : "Зменены тэкст адмовы ад адказнасці",
    "Deleted disclaimer text" : "Выдалены тэкст адмовы ад адказнасці",
    "Could not set disclaimer text" : "Не ўдалося задаць тэкст адмовы ад адказнасці",
    "Allow apps to use the Share API" : "Дазволіць праграмам выкарыстоўваць API абагульвання",
    "Allow users to share via link and emails" : "Дазволіць карыстальнікам абагульваць праз спасылку і электронную пошту",
    "Allow public uploads" : "Дазволіць публічныя запампоўванні",
    "Always ask for a password" : "Заўсёды пытацца пароль",
    "Exclude groups from password requirements" : "Выключыць групы з патрабаванняў да пароляў",
    "Exclude groups from creating link shares" : "Выключыць групы з магчымасці стварэння абагуленых спасылак",
    "Allow users to set custom share link tokens" : "Дазволіць карыстальнікам задаваць уласныя токены абагуленых спасылак",
    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Абагульванні з карыстальніцкімі токенамі будуць даступныя і пасля адключэння гэтай налады",
    "Shares with guessable tokens may be accessed easily" : "Да абагульванняў з токенамі, якія можна адгадаць, лёгка атрымаць доступ",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Паказваць тэкст адмовы ад адказнасці на старонцы запампоўвання публічнай спасылкі (паказваецца, толькі калі спіс файлаў схаваны)",
    "Disclaimer text" : "Тэкст адмовы ад адказнасці",
    "This text will be shown on the public link upload page when the file list is hidden." : "Гэты тэкст будзе паказвацца на старонцы запампоўвання публічнай спасылкі, калі спіс файлаў схаваны.",
    "Default share permissions" : "Прадвызначаныя дазволы на абагульванне",
    "Two-Factor Authentication" : "Двухфактарная аўтэнтыфікацыя",
    "Excluded groups" : "Выключаныя групы",
    "Save changes" : "Захаваць змены",
    "Default" : "Прадвызначаныя",
    "Update to {update}" : "Абнаўленне да {update}",
    "Remove" : "Выдаліць",
    "Disable all" : "Адключыць усе",
    "Download and enable all" : "Спампаваць і уключыць усе",
    "All apps are up-to-date." : "Усе праграмы абноўлены.",
    "Icon" : "Значок",
    "Name" : "Назва",
    "Version" : "Версія",
    "Level" : "Узровень",
    "Actions" : "Дзеянні",
    "Results from other categories" : "Вынікі з іншых катэгорый",
    "No apps found for your version" : "Для вашай версіі праграм не знойдзена",
    "_%n app has an update available_::_%n apps have an update available_" : ["Дастыпна абнаўленне для %n праграмы","Дастыпны абнаўленні для %n праграм","Дастыпны абнаўленні для %n праграм","Дастыпны абнаўленні для %n праграм"],
    "_Update_::_Update all_" : ["Абнавіць","Абнавіць усе","Абнавіць усе","Абнавіць усе"],
    "Failed to load groups" : "Не атрымалася загрузіць групы",
    "Failed to create group" : "Не атрымалася стварыць групу",
    "Creating group…" : "Стварэнне групы…",
    "Create group" : "Стварыць групу",
    "Group name" : "Назва групы",
    "Search groups…" : "Пошук груп…",
    "Loading groups…" : "Загрузка груп…",
    "Nothing to show" : "Няма чаго паказаць",
    "Loading" : "Загрузка",
    "Carousel" : "Карусель",
    "Previous slide" : "Папярэдні слайд",
    "Next slide" : "Наступны слайд",
    "{index} of {total}" : "{index} з {total}",
    "Type" : "Тып",
    "Display Name" : "Імя для паказу",
    "Learn more" : "Больш падрабязна",
    "Environment variables" : "Пераменныя асяроддзя",
    "Confirm" : "Пацвердзіць",
    "Cancel" : "Скасаваць",
    "Description" : "Апісанне",
    "Visit website" : "Наведаць вэб-сайт",
    "Details" : "Падрабязнасці",
    "All" : "Усе",
    "No results" : "Няма вынікаў",
    "Update to {version}" : "Абнаўленне да {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Гэта праграма не можа быць усталявана, бо не выкананы наступныя залежнасці:",
    "Latest updated" : "Апошняе абнаўленне",
    "Author" : "Аўтар",
    "Categories" : "Катэгорыі",
    "Resources" : "Рэсурсы",
    "Documentation" : "Дакументацыя",
    "Report a bug" : "Паведаміць пра памылку",
    "Rate the app" : "Ацаніце праграму",
    "Rate" : "Ацаніць",
    "Google Chrome for Android" : "Google Chrome для Android",
    "This session" : "Гэты сеанс",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Назва прылады",
    "Cancel renaming" : "Скасаваць перайменаванне",
    "Save new name" : "Захаваць новую назву",
    "Device settings" : "Налады прылады",
    "Rename" : "Перайменаваць",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Адмена гэтага токена можа прадухіліць ачыстку вашай прылады, калі працэс яшчэ не пачаўся.",
    "Device" : "Прылада",
    "Last activity" : "Апошняя актыўнасць",
    "Devices & sessions" : "Прылады і сеансы",
    "Error while creating device token" : "Памылка пры стварэнні токена прылады",
    "App name" : "Назва праграмы",
    "Login name copied!" : "Лагін скапіяваны!",
    "Copy login name" : "Скапіяваць лагін",
    "Login" : "Лагін",
    "Password" : "Пароль",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (Рэкамендуецца)",
    "Profile" : "Профіль",
    "Server-side encryption" : "Шыфраванне на баку сервера",
    "Enable server-side encryption" : "Уключыць шыфраванне на баку сервера",
    "Cancel encryption" : "Скасаваць шыфраванне",
    "Enable encryption" : "Уключыць шыфраванне",
    "Confirm enabling encryption" : "Пацвердзіце ўключэнне шыфравання",
    "Please read carefully before activating server-side encryption:" : "Уважліва прачытайце перад актывацыяй шыфравання на баку сервера:",
    "Be aware that encryption always increases the file size." : "Майце на ўвазе, што шыфраванне заўсёды павялічвае памер файла.",
    "This is the final warning: Do you really want to enable encryption?" : "Гэта апошняе папярэджанне: Вы сапраўды хочаце ўключыць шыфраванне?",
    "Failed to delete group \"{group}\"" : "Не ўдалося выдаліць групу \"{group}\"",
    "Please confirm the group removal" : "Пацвердзіце выдаленне групы",
    "You are about to delete the group \"{group}\". The accounts will NOT be deleted." : "Вы збіраецеся выдаліць групу \"{group}\". Уліковыя запісы НЕ будуць выдалены.",
    "Submit" : "Адправіць",
    "Rename group" : "Перайменаваць групу",
    "Delete group" : "Выдаліць групу",
    "Current password" : "Бягучы пароль",
    "New password" : "Новы пароль",
    "Change password" : "Змяніць пароль",
    "Choose your profile picture" : "Выберыце аватар профілю",
    "Error setting profile picture" : "Памылка задання аватара профілю",
    "Error cropping profile picture" : "Памылка абрэзкі аватара профілю",
    "Error saving profile picture" : "Памылка захавання аватара профілю",
    "Error removing profile picture" : "Памылка выдалення аватара профілю",
    "Your profile picture" : "Ваш аватар профілю",
    "Upload profile picture" : "Запампаваць аватар профілю",
    "Choose profile picture from Files" : "Выбраць аватар профілю з Файлаў",
    "Remove profile picture" : "Выдаліць аватар профілю",
    "The file must be a PNG or JPG" : "Файл павінен быць у фармаце PNG або JPG",
    "Set as profile picture" : "Задаць як аватар профілю",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Звярніце ўвагу, што абнаўленне вашага аватара профілю паўсюль можа заняць да 24 гадзін.",
    "Your biography. Markdown is supported." : "Ваша біяграфія. Падтрымліваецца Markdown.",
    "Unable to update date of birth" : "Немагчыма абнавіць дату нараджэння",
    "Enter your date of birth" : "Увядзіце дату нараджэння",
    "You are using {s}{usage}{/s}" : "Вы выкарыстоўваеце {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Вы выкарыстоўваеце {s}{usage}{/s} з {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "Your full name" : "Ваша поўнае імя",
    "No email address set" : "Адрас электроннай пошты не зададзены",
    "Derived from your locale ({weekDayName})" : "Паходзіць з вашай лакалі ({weekDayName})",
    "Unable to update first day of week" : "Немагчыма абнавіць першы дзень тыдня",
    "Day to use as the first day of week" : "Дзень, які выкарыстоўваецца ў якасці першага дня тыдня",
    "Your headline" : "Ваш загаловак",
    "Unable to update language" : "Немагчыма абнавіць мову",
    "Languages" : "Мовы",
    "Help translate" : "Дапамагчы з перакладам",
    "No language set" : "Мова не зададзена",
    "Unable to update locale" : "Немагчыма абнавіць лакаль",
    "Locales" : "Лакалі",
    "Week starts on {firstDayOfWeek}" : "Тыдзень пачынаецца з {firstDayOfWeek}",
    "No locale set" : "Лакаль не зададзена",
    "Your city" : "Ваш горад",
    "Your organisation" : "Ваша арганізацыя",
    "Your phone number" : "Ваш нумар тэлефона",
    "Enable profile" : "Уключыць профіль",
    "she/her" : "яна",
    "he/him" : "ён",
    "they/them" : "яны",
    "Your pronouns. E.g. {pronounsExample}" : "Вашы займеннікі. Напрыклад, {pronounsExample}",
    "Your role" : "Ваша роля",
    "Timezone" : "Часавы пояс",
    "Your website" : "Ваш вэб-сайт",
    "Add" : "Дадаць",
    "Create" : "Стварыць",
    "Change" : "Змяніць",
    "Delete" : "Выдаліць",
    "Enabled applications" : "Уключаныя праграмы",
    "Disabled applications" : "Адключаныя праграмы",
    "University" : "Універсітэт",
    "School" : "Школа",
    "Club or association" : "Клуб або асацыяцыя",
    "Family" : "Сям'я",
    "Personal use" : "Асабістае выкарыстанне",
    "Default language" : "Прадвызначаная мова",
    "Other languages" : "Іншыя мовы",
    "No accounts" : "Няма ўліковых запісаў",
    "Loading accounts …" : "Загрузка ўліковых запісаў …",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Спіс уліковых запісаў. Гэты спіс не апрацоўваецца цалкам з меркаванняў прадукцыйнасці. Уліковыя запісы будуць апрацоўвацца па меры навігацыі па спісе.",
    "Manager" : "Менеджар",
    "Account name will be autogenerated" : "Імя ўліковага запісу будзе згенерыравана аўтаматычна",
    "Account name (required)" : "Імя ўліковага запісу (абавязкова)",
    "New account" : "Новы ўліковы запіс",
    "Display name" : "Імя для паказу",
    "Password (required)" : "Пароль (абавязкова)",
    "Email (required)" : "Электронная пошта (абавязкова)",
    "Email" : "Электронная пошта",
    "Set account as admin for …" : "Задаць уліковы запіс у якасці адміністратара для …",
    "Quota" : "Квота",
    "Set account quota" : "Задаць квоту ўліковага запісу",
    "Language" : "Мова",
    "Set default language" : "Задаць прадвызначаную мову",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} уліковы запіс …","{userCount} уліковыя запісы …","{userCount} уліковых запісаў …","{userCount} уліковых запісаў …"],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} уліковы запіс","{userCount} уліковыя запісы","{userCount} уліковых запісаў","{userCount} уліковых запісаў"],
    "Total rows summary" : "Зводка па ўсіх радках",
    "Avatar" : "Аватар",
    "Account name" : "Імя ўліковага запісу",
    "{size} used" : "Выкарыстана {size}",
    "Delete account" : "Выдаліць уліковы запіс",
    "Disable account" : "Адключыць уліковы запіс",
    "Enable account" : "Уключыць уліковы запіс",
    "Account deletion" : "Выдаленне ўліковага запісу",
    "Display name was successfully changed" : "Імя для паказу паспяхова зменена",
    "Loading account …" : "Загрузка ўліковага запісу …",
    "Change display name" : "Змяніць імя для паказу",
    "Set new password" : "Задаць новы пароль",
    "Add account to group" : "Дадаць уліковы запіс у групу",
    "Select account quota" : "Выберыце квоту ўліковага запісу",
    "Set the language" : "Задайце мову",
    "Done" : "Гатова",
    "Edit" : "Рэдагаваць",
    "Account management settings" : "Налады кіравання ўліковымі запісамі",
    "Visibility" : "Бачнасць",
    "Show language" : "Паказаць мову",
    "Sorting" : "Сартаванне",
    "Group list sorting" : "Сартаванне спіса груп",
    "By member count" : "Па колькасці ўдзельнікаў",
    "By name" : "Па назве",
    "Send email" : "Адправіць электронны ліст",
    "Default quota" : "Прадвызначаная квота",
    "Select default quota" : "Выберыце прадвызначаную квоту",
    "Add WebAuthn device" : "Дадаць прыладу WebAuthn",
    "Adding your device …" : "Дадаванне вашай прылады …",
    "Unnamed device" : "Прылада без назвы",
    "No devices configured." : "Няма сканфігураваных прылад.",
    "Your browser does not support WebAuthn." : "Ваш браўзер не падтрымлівае WebAuthn.",
    "Please double check the {linkStartInstallationGuides}installation guides{linkEnd}, and check for any errors or warnings in the {linkStartLog}log{linkEnd}." : "Яшчэ раз праверце {linkStartInstallationGuides}інструкцыю па ўсталяванні{linkEnd} і праверце наяўнасць памылак або папярэджанняў у {linkStartLog}журнале{linkEnd}.",
    "Checking your server …" : "Праверка сервера …",
    "Try again" : "Паспрабаваць яшчэ раз",
    "Loading app list" : "Загрузка спіса праграм",
    "Loading categories" : "Загрузка катэгорый",
    "Developer documentation ↗" : "Дакументацыя распрацоўшчыка ↗",
    "Version {version}, {license}-licensed" : "Версія {version}, ліцэнзія {license}",
    "Version {version}" : "Версія {version}",
    "Apply" : "Ужыць",
    "All accounts" : "Усе ўліковыя запісы",
    "Admins" : "Адміністратары",
    "Account management" : "Кіраванне ўліковымі запісамі",
    "Sending…" : "Адпраўка…",
    "Location" : "Месцазнаходжанне",
    "Profile picture" : "Аватар профілю",
    "About" : "Пра сябе",
    "Date of birth" : "Дата нараджэння",
    "Full name" : "Поўнае імя",
    "Headline" : "Загаловак",
    "Organisation" : "Арганізацыя",
    "Phone number" : "Нумар тэлефона",
    "Pronouns" : "Займеннікі",
    "Role" : "Роля",
    "X (formerly Twitter)" : "X (былы Twitter)",
    "Bluesky" : "Bluesky",
    "Website" : "Вэб-сайт",
    "Locale" : "Лакаль",
    "First day of week" : "Першы дзень тыдня",
    "timezone" : "часавы пояс",
    "Your apps" : "Вашы праграмы",
    "Active apps" : "Актыўныя праграмы",
    "Disabled apps" : "Адключаныя праграмы",
    "Updates" : "Абнаўленні",
    "App bundles" : "Наборы праграм",
    "Featured apps" : "Папулярныя праграмы",
    "Supported apps" : "Праграмы, якія падтрымліваюцца",
    "Show to everyone" : "Паказаць усім",
    "Hide" : "Схаваць",
    "Download and enable" : "Спампаваць і ўключыць",
    "Disable" : "Адключыць",
    "Allow untested app" : "Дазволіць неправераную праграму",
    "Unknown" : "Невядомы",
    "Never" : "Ніколі",
    "Could not register device" : "Не ўдалося зарэгістраваць прыладу",
    "An error occurred during the request. Unable to proceed." : "Падчас запыту адбылася памылка. Не ўдалося працягнуць.",
    "The app has been enabled but needs to be updated." : "Праграма ўключана, але патрабуе абнаўлення.",
    "Could not delete the app token" : "Не атрымалася выдаліць токен праграмы",
    "Error while wiping the device with the token" : "Памылка падчас ачысткі прылады з токенам",
    "Error while updating device token name" : "Памылка падчас абнаўлення назвы токена прылады",
    "Error while updating device token scope" : "Памылка падчас абнаўлення вобласці дзеяння токена прылады",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "З вашай сеткі паступіла занадта шмат запытаў. Паўтарыце спробу пазней або звярніцеся да адміністратара, калі гэта памылка.",
    "Error" : "Памылка",
    "Forum" : "Форум",
    "Privacy policy" : "Палітыка прыватнасці",
    "SSL" : "SSL",
    "Open documentation" : "Адкрыць дакументацыю",
    "Encryption" : "Encryption",
    "Server address" : "Адрас сервера",
    "Port" : "Порт",
    "Authentication" : "Аўтэнтыфікацыя",
    "Authentication required" : "Патрабуецца аўтэнтыфікацыя",
    "Credentials" : "Уліковыя даныя",
    "SMTP Login" : "Лагін SMTP",
    "SMTP Password" : "Пароль SMTP",
    "Save" : "Захаваць",
    "Reasons to use Nextcloud in your organization" : "Прычыны выкарыстоўваць Nextcloud у вашай арганізацыі",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Распрацоўваецца {communityopen}супольнасцю Nextcloud{linkclose}, {githubopen}зыходны код{linkclose} распаўсюджваецца па ліцэнзіі {licenseopen}AGPL{linkclose}.",
    "Check out our blog" : "Азнаёмцеся з нашым блогам",
    "Subscribe to our newsletter" : "Падпішыцеся на нашу рассылку",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Гэтай праграме не прызначана мінімальная версія Nextcloud. У будучыні гэта будзе памылкай.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Гэтай праграме не прызначана максімальная версія Nextcloud. У будучыні гэта будзе памылкай.",
    "Your biography" : "Ваша біяграфія",
    "You are using <strong>{usage}</strong>" : "Вы выкарыстоўваеце <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Вы выкарыстоўваеце <strong>{usage}</strong> з <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
